@@ -156,6 +156,26 @@ function proon_consider_count(&$p, &$m, $countspan) {
   $m[PROON_M_DUE_TO_COUNT] = count($m[PROON_M_TO_PRUNE]) - $oldcount;
 }
 
+/**
+ * Takes an SM mailbox 'RIGHTS' attribute and interprets it to figure
+ * out if the folder is READ-WRITE.  This seems strightforward since
+ * the IMAP spec says it should be the literal string 'READ-WRITE'.
+ * We relax that to be case-insensitive, and we'll accept it if it
+ * contains that string instead of being exactly equal.  Also, at least
+ * one IMAP server answer 'READ_WRITE' with an underscore, so check for
+ * that, too.  If the proon config variable proon_readwrite_check is
+ * false, skip all that and just answer yes.  If proon_readwrite_check
+ * is a string, look for it.
+ */
+function proon_is_readwrite(&$rights) {
+  global $proon_readwrite_check;
+  if (! $proon_readwrite_check) return true;
+  if (stristr($rights, 'READ-WRITE')) return true;
+  if (stristr($rights, 'READ_WRITE')) return true;
+  if (is_string($proon_readwrite_check)  &&  stristr($rights, $proon_readwrite_check)) return true;
+  return false;
+}
+
 /**
  * Given a target folder, get the list of messages, shuffle through
  * them according to pruing criteria, and truen the list of UIDs
@@ -184,10 +204,10 @@ function proon_get_uids_one_folder(&$p, $target, $select_target, $spans, &$imapS
   $m[PROON_M_MBOX] = $mbx;
   if ($mbx['EXISTS'] == 0) return $m;
 
-  if ((strtoupper($mbx['RIGHTS'])) != "READ-WRITE") {
-    // No write access to the folder, so can't prune it.
-    return false;
-  }
+  global $proon_readwrite_check;
+
+  sm_print_r('Rights', $mbx['RIGHTS']);
+  if (!proon_is_readwrite($mbx['RIGHTS'])) return $m;
 
   $toss_unseen = isset($p[PROON_F_UNSEENS][$target]);
 
@@ -218,10 +238,16 @@ function proon_get_uids_one_folder(&$p, $target, $select_target, $spans, &$imapS
     }
   }
 
-  proon_consider_date($p, $m, $spans[PROON_SPAN_DATE]);
+  if (!isset($p[PROON_P_OPTIONS][PROON_O_U_DIS_DATE])) {
+    proon_consider_date($p, $m, $spans[PROON_SPAN_DATE]);
+  }
   proon_sort_conveniently($p, $m, $spans[PROON_SPAN_DATE], $spans[PROON_SPAN_COUNT]);
-  proon_consider_size($p, $m, $spans[PROON_SPAN_SIZE]);
-  proon_consider_count($p, $m, $spans[PROON_SPAN_COUNT]);
+  if (!isset($p[PROON_P_OPTIONS][PROON_O_U_DIS_SIZE])) {
+    proon_consider_size($p, $m, $spans[PROON_SPAN_SIZE]);
+  }
+  if (!isset($p[PROON_P_OPTIONS][PROON_O_U_DIS_COUNT])) {
+    proon_consider_count($p, $m, $spans[PROON_SPAN_COUNT]);
+  }
 
   return $m;
 }
@@ -243,7 +269,9 @@ function proon_action_save(&$p, &$outcome, &$notice) {
     $raw = $p[PROON_P_OPTIONS][PROON_O_U_PRUNE_INTERVAL];
     $cooked = proon_date_in_seconds($raw);
     if ($cooked === false) {
+      proon_locale_on();
       $notice .= _("Problem with '").PROON_UI_INTERVAL.'\'.  ';
+      proon_locale_off();
       $ok_to_save = false;
     }
   }
@@ -264,7 +292,9 @@ function proon_action_save(&$p, &$outcome, &$notice) {
     $dirty = false;
   }
   else {
+    proon_locale_on();
     $notice .= _("Values were NOT saved due to a problem in one or more fields.");
+    proon_locale_off();
     $dirty = true;
   }
   return $dirty;
@@ -275,11 +305,17 @@ function proon_action_save(&$p, &$outcome, &$notice) {
  */
 function proon_number_tail(&$a) {
   $duedate = $a[PROON_OUTCOME_DUE_TO_DATE];
+  if (!$duedate) $duedate = 0;
   $duesize = $a[PROON_OUTCOME_DUE_TO_SIZE];
+  if (!$duesize) $duesize = 0;
   $duecount = $a[PROON_OUTCOME_DUE_TO_COUNT];
+  if (!$duecount) $duecount = 0;
+  // someone reported seeing blank instead of 0, so the above "if" is to 
+  // try to counteract that
 
   $tot = $duedate + $duesize + $duecount;
   $original = $a[PROON_OUTCOME_TOTAL_BEFORE];
+  if (!$original) $original = 0;
   $leave = $original - $tot;
   $numbers = "$original - ($duedate + $duesize + $duecount) = $leave";
   return $numbers;
@@ -327,7 +363,9 @@ function proon_action_now_or_effect(&$p, &$target, &$outcome, &$imapStr, $doit)
   }
   proon_login($imapStr);
   if (! sqimap_mailbox_exists($imapStr, $select_target)) {
+    proon_locale_on();
     $outcome[$target][PROON_OUTCOME_ERROR] = _("Folder doesn't exist.");
+    proon_locale_off();
     //sm_print_r('outcome', $outcome);
     return false;
   }
@@ -346,7 +384,9 @@ function proon_action_now_or_effect(&$p, &$target, &$outcome, &$imapStr, $doit)
 
   $numbers = proon_number_tail($outcome[$target]);
   if ($doit) {
+    proon_locale_on();
     $outcome[$target][PROON_OUTCOME_PRUNE] = _("Messages (pruned):").'  '. $numbers;
+    proon_locale_off();
     if (count($m[PROON_M_TO_PRUNE]) > 0) {
       global $move_to_trash, $trash_folder, $folder_prefix;
       $old_move_to_trash = $move_to_trash;
@@ -363,7 +403,9 @@ function proon_action_now_or_effect(&$p, &$target, &$outcome, &$imapStr, $doit)
     }
   }
   else {
+    proon_locale_on();
     $outcome[$target][PROON_OUTCOME_EFFECT] = _("Messages (to prune):").'  '. $numbers;
+    proon_locale_off();
   }
   return true;
 }
@@ -420,7 +462,9 @@ function proon_action_effect_or_prune_all(&$p, &$outcome, &$notice, &$imapStr, $
   }
   $notice = false;
   if ($doit  &&  $pruneall_notice) {
+    proon_locale_on();
     $notice = _("Some folders WERE NOT pruned due to improper date, size, or count spans.  See the folder list below for details.  Those without problems WERE pruned.");
+    proon_locale_off();
   }
   return;
 }
