@@ -1,5 +1,38 @@
 <?php
 
+include_once(SM_PATH . 'plugins/proon/site-config.php.sample');
+if (file_exists(SM_PATH . 'plugins/proon/site-config.php')) {
+  include(SM_PATH . 'plugins/proon/site-config.php');
+}
+
+function proon_locale_on($s = false) {
+  global $proon_log_verbose;
+  $s && $proon_log_verbose && proon_log('L ON  ' . $s);
+  $old = textdomain(null);
+  if ($old == 'proon') {
+    return;
+  }
+  global $proon_old_textdomain;
+  $proon_old_textdomain = $old;
+  bindtextdomain('proon', SM_PATH . 'locale');
+  textdomain('proon');
+}
+
+function proon_locale_off($s = false) {
+  global $proon_old_textdomain, $proon_log_verbose;
+  $s && $proon_log_verbose && proon_log('L OFF ' . $s);
+  $new = textdomain(null);
+  if ($new != 'proon') {
+    return;
+  }
+  bindtextdomain('squirrelmail', SM_PATH . 'locale');
+  if (! $proon_old_textdomain) {
+    $proon_old_textdomain = 'squirrelmail';
+  }
+  textdomain($proon_old_textdomain);
+}
+
+
 include_once(SM_PATH . 'plugins/proon/define.php');
 include_once(SM_PATH . 'plugins/proon/defineui.php');
 
@@ -110,20 +143,32 @@ function proon_logout(& $imapStr) {
 
 function proon_check_spans(&$spans, $rawdate, $rawsize, $rawcount) {
   if (!$rawdate  &&  !$rawsize  &&  !$rawcount) {
-    return _("None of the span values has been set for this folder.");
+    proon_locale_on();
+    $m = _("None of the span values has been set for this folder.");
+    proon_locale_off();
+    return $m;
   }
   $datespan = proon_date_in_seconds($rawdate);
   $sizespan = proon_size_in_bytes($rawsize);
   $countspan = proon_count_in_each($rawcount);
 
   if ($rawdate != ''  &&  $datespan === false) {
-    return _("The date span is malformed.");
+    proon_locale_on();
+    $m = _("The date span is malformed.");
+    proon_locale_off();
+    return $m;
   }
   if ($rawsize != ''  &&  $sizespan === false) {
-    return _("The size span is malformed.");
+    proon_locale_on();
+    $m = _("The size span is malformed.");
+    proon_locale_off();
+    return $m;
   }
   if ($rawcount != ''  &&  $countspan === false) {
-    return _("The count span is malformed.");
+    proon_locale_on();
+    $m = _("The count span is malformed.");
+    proon_locale_off();
+    return $m;
   }
   $spans[PROON_SPAN_DATE] = $datespan;
   $spans[PROON_SPAN_SIZE] = $sizespan;
@@ -410,25 +455,6 @@ function proon_is_dirty(&$p) {
   return proon_arrays_differ($p[PROON_P_OPTIONS], $pref_p[PROON_P_OPTIONS]);
 }
 
-function proon_log_delta($tag, $t1, $t2 = null, $folder = null) {
-  if ($t2 == null) $t2 = microtime();
-  list($u1, $s1) = explode(' ', $t1);
-  list($u2, $s2) = explode(' ', $t2);
-  $delta = (($s2-$s1) + ($u2-$u1));
-  $delta = substr($delta, 0, 8); // ought to be enough precision for any geek
-  proon_log($delta.' '.$tag, $folder);
-}
-
-function proon_log($s, $folder = null) {
-  global $proon_log_file;
-  if ($proon_log_file != null) {
-    $l = fopen($proon_log_file, 'a+');
-    $f = ($folder ? "[$folder] " : '');
-    fputs($l, date('Y-m-d H:i:s O').' ['.$_SESSION['username'].'] '.$f); fputs($l, $s); fputs($l, "\n");
-    fflush($l);
-  }
-}
-
 function proon_calc_report_widths(&$p, &$outcome, $verbose) {
   $w = array();
   $w['duelabel'] = max(strlen(PROON_UI_DATE_SPAN), 
@@ -438,12 +464,15 @@ function proon_calc_report_widths(&$p, &$outcome, $verbose) {
   $w['fname'] = strlen(PROON_UI_FOLDER);
   $w['spanval'] = 0;
   $w['total'] = 0;
+  proon_locale_on();
+  $yess = _("yes");
+  proon_locale_off();
   foreach ($outcome as $f => $an) {
-    $w['fname'] = max($w['fname'], strlen($f));
+    $w['fname'] = max($w['fname'], strlen(proon_folder_blat_name($f)));
     $d = isset($p[PROON_F_DATES][$f]) ? $p[PROON_F_DATES][$f] : '';
     $s = isset($p[PROON_F_SIZES][$f]) ? $p[PROON_F_SIZES][$f] : '';
     $c = isset($p[PROON_F_COUNTS][$f]) ? $p[PROON_F_COUNTS][$f] : '';
-    $u = isset($p[PROON_F_UNSEENS][$f]) ? _("yes") : '';
+    $u = isset($p[PROON_F_UNSEENS][$f]) ? $yess : '';
     $w['spanval'] = max($w['spanval'], strlen($d), strlen($s), strlen($c), strlen($u));
     $dp = $an[PROON_OUTCOME_DUE_TO_DATE];
     $sp = $an[PROON_OUTCOME_DUE_TO_SIZE];
@@ -461,6 +490,9 @@ function proon_format_outcome(&$p, &$outcome, $verbose) {
   $format_p = '    %'.$w['duelabel'].'s [%'.$w['spanval'].'s]: %3s'."\n";
   $report = null;
   $did_legend = false;
+  proon_locale_on();
+  $yess = _("yes");
+  proon_locale_off();
   foreach ($outcome as $f => $f_out) {
     $d = isset($p[PROON_F_DATES][$f]) ? $p[PROON_F_DATES][$f] : '';
     $s = isset($p[PROON_F_SIZES][$f]) ? $p[PROON_F_SIZES][$f] : '';
@@ -475,10 +507,13 @@ function proon_format_outcome(&$p, &$outcome, $verbose) {
     $span_value_width = max(strlen($d), strlen($s), strlen($c));
     $tot_before = $f_out[PROON_OUTCOME_TOTAL_BEFORE];
     if (! $did_legend) {
+      proon_locale_on();
       $report .= sprintf($format_f, PROON_UI_FOLDER.':', _("Remainder"), _("Before"), _("Pruned"), '');
+      proon_locale_off();
       $did_legend = true;
     }
-    $report .= sprintf($format_f, $f.':', ($tot_before - $tot_pruned), $tot_before, $tot_pruned, $err);
+    $fI18N = proon_folder_blat_name($f);
+    $report .= sprintf($format_f, $fI18N.':', ($tot_before - $tot_pruned), $tot_before, $tot_pruned, $err);
     if ($d !== ''  &&  $d !== null) {
       $report .= sprintf($format_p, PROON_UI_DATE_SPAN, $d, $dp);
     }
@@ -489,13 +524,23 @@ function proon_format_outcome(&$p, &$outcome, $verbose) {
       $report .= sprintf($format_p, PROON_UI_COUNT_SPAN, $c, $cp);
     }
     if ($u !== ''  &&  $u !== null) {
-      $report .= sprintf($format_p, PROON_UI_UNSEEN_TOO, _("yes"), '');
+      $report .= sprintf($format_p, PROON_UI_UNSEEN_TOO, $yess, '');
     }
     $report .= "\n\n";
   }
   return $report;
 }
 
+function proon_folder_blat_name($folder) {
+  if (strcasecmp('INBOX', $folder) == 0) {
+    $folderI18N = _("INBOX");
+  }
+  else {
+    $folderI18N = imap_utf7_decode_local($folder);
+  }
+  return $folderI18N;
+}
+
 function proon_format_headers(&$p, &$outcome, $verbose) {
   $w = proon_calc_report_widths($p, $outcome, $verbose);
   include_once(SM_PATH . 'class/mime/Rfc822Header.class.php');
@@ -504,7 +549,9 @@ function proon_format_headers(&$p, &$outcome, $verbose) {
   // fare well with those when they are displayed.
   global $proon_site_from_address;
   $f = 'From: '.$proon_site_from_address."\r\n";
+  proon_locale_on();
   $s = 'Subject: '._("Messages automatically pruned:").' '.$w['total']."\r\n";
+  proon_locale_off();
   $hdr->parseHeader($f . $s);
   return $hdr;
 }
@@ -531,4 +578,23 @@ function proon_is_subscribed(&$p, &$target, $imapStr) {
   return (isset($p[PROON_P_BOXNAMES][$target]));
 }
 
+function proon_log_delta($tag, $t1, $t2 = null, $folder = null) {
+  if ($t2 == null) $t2 = microtime();
+  list($u1, $s1) = explode(' ', $t1);
+  list($u2, $s2) = explode(' ', $t2);
+  $delta = (($s2-$s1) + ($u2-$u1));
+  $delta = substr($delta, 0, 8); // ought to be enough precision for any geek
+  proon_log($delta.' '.$tag, $folder);
+}
+
+function proon_log($s, $folder = null) {
+  global $proon_log_file;
+  if ($proon_log_file != null) {
+    $l = fopen($proon_log_file, 'a+');
+    $f = ($folder ? "[$folder] " : '');
+    fputs($l, date('Y-m-d H:i:s O').' ['.$_SESSION['username'].'] '.$f); fputs($l, $s); fputs($l, "\n");
+    fflush($l);
+  }
+}
+
 ?>
